/*
  This program and the accompanying materials are
  made available under the terms of the Eclipse Public License v2.0 which accompanies
  this distribution, and is available at https://www.eclipse.org/legal/epl-v20.html

  SPDX-License-Identifier: EPL-2.0

  Copyright Contributors to the Zowe Project.
*/

#ifndef RSCRYPTO_ERRORS_H_
#define RSCRYPTO_ERRORS_H_

//errors
#ifndef RS_SUCCESS
#define RS_SUCCESS					0
#endif

#define RSCRYPTO_BASE_ERROR 			7770000

#define RSCRYPTO_INVALID_ARGUMENT				(RSCRYPTO_BASE_ERROR + 1)
#define RSCRYPTO_INSUFFICIENT_OUTPUT_SPACE		(RSCRYPTO_BASE_ERROR + 2)
#define RSCRYPTO_CALLABLE_SERVICE_ERROR			(RSCRYPTO_BASE_ERROR + 3)
#define RSCRYPTO_UNSUPPORTED_KEY_TYPE			(RSCRYPTO_BASE_ERROR + 4)
#define RSCRYPTO_UNSUPPORTED_ALGORITHM			(RSCRYPTO_BASE_ERROR + 5)
#define RSCRYPTO_UNSUPPORTED_KEY_LENGTH			(RSCRYPTO_BASE_ERROR + 6)
#define RSCRYPTO_INSUFFICIENT_IV_LENGTH			(RSCRYPTO_BASE_ERROR + 7)
#define RSCRYPTO_INSUFFICIENT_CIPHERTEXT_LENGTH 	(RSCRYPTO_BASE_ERROR + 8)
#define RSCRYPTO_CONTEXT_VALIDATION_FAILED		(RSCRYPTO_BASE_ERROR + 9)
#define RSCRYPTO_INSUFFICIENT_CLEARTEXT_LENGTH	(RSCRYPTO_BASE_ERROR + 10)
#define RSCRYPTO_CIPHERTEXT_INPUT_LENGTH_WARNING	(RSCRYPTO_BASE_ERROR + 11)
#define RSCRYPTO_PKCS_PADDING_MALFORMED_WARNING  (RSCRYPTO_BASE_ERROR + 12)
#define RSCRYPTO_INSUFFICIENT_KEY_DATA_LENGTH    (RSCRYPTO_BASE_ERROR + 13)
#define RSCRYPTO_ALLOC_FAILED                    (RSCRYPTO_BASE_ERROR + 14)
#define RSCRYPTO_KEYSRC_NO_PLUGIN				(RSCRYPTO_BASE_ERROR + 15)
#define RSCRYPTO_UNSUPPORTED_KEYSRC_TYPE         (RSCRYPTO_BASE_ERROR + 16)
#define RSCRYPTO_DIGEST_ALORITHM_MISMATCH        (RSCRYPTO_BASE_ERROR + 17)
#define RSCRYPTO_INVALID_IDENTIFIER_LENGTH       (RSCRYPTO_BASE_ERROR + 18)
#define RSCRYPTO_KEY_LABEL_NOTFOUND              (RSCRYPTO_BASE_ERROR + 19)
#define RSCRYPTO_BASE64_DECODE_ERROR				(RSCRYPTO_BASE_ERROR + 20)
#define RSCRYPTO_PEM_DECODE_ERROR                (RSCRYPTO_BASE_ERROR + 21)
#define RSCRYPTO_KEY_LABEL_EXISTS                (RSCRYPTO_BASE_ERROR + 22)
#define RSCRYPTO_KEY_COMPARISON_NOTEQUAL         (RSCRYPTO_BASE_ERROR + 23)
#define RSCRYPTO_KEY_COMPARISON_EQUAL			RS_SUCCESS

#define RSCRYPTO_FILE_ERROR               (RSCRYPTO_BASE_ERROR + 25)

#define RSCRYPTO_PUBKEYINFO_NOT_FOUND			(RSCRYPTO_BASE_ERROR + 30)
#define RSCRYPTO_ASN1_PARSE_ERROR				(RSCRYPTO_BASE_ERROR + 31)
#define RSCRYPTO_PRIVKEYINFO_NOT_FOUND           (RSCRYPTO_BASE_ERROR + 32)
#define RSCRYPTO_ATTRLIST_PARSE_ERROR     (RSCRYPTO_BASE_ERROR + 33)
#define RSCRYPTO_APPATTR_NOT_FOUND        (RSCRYPTO_BASE_ERROR + 34)


#define RSCRYPTO_OATH_INVALID_TIME        (RSCRYPTO_BASE_ERROR + 40)

#define RSCRYPTO_PLUGIN_LOAD_ERROR				(RSCRYPTO_BASE_ERROR + 200)
#define RSCRYPTO_PLUGIN_SYMBOL_NOT_FOUND			(RSCRYPTO_BASE_ERROR + 201)
#define RSCRYPTO_PLUGIN_CREATEINSTANCE_FAILED    (RSCRYPTO_BASE_ERROR + 202)
#define RSCRYPTO_PLUGIN_LOOKUP_FAILED            (RSCRYPTO_BASE_ERROR + 203)

#define RSCRYPTO_ICSF_ERROR_BASE				(RSCRYPTO_BASE_ERROR + 1000)

#define RSCRYPTO_CKDS_LABEL_NOTFOUND			(RSCRYPTO_ICSF_ERROR_BASE + 1)
#define RSCRYPTO_PKDS_LABEL_NOTFOUND			(RSCRYPTO_ICSF_ERROR_BASE + 2)
#define RSCRYPTO_CKDS_RECORD_EXISTS				(RSCRYPTO_ICSF_ERROR_BASE + 3)
#define RSCRYPTO_PKDS_RECORD_EXISTS				(RSCRYPTO_ICSF_ERROR_BASE + 4)
#define RSCRYPTO_CKDS_CREATE_FAILED				(RSCRYPTO_ICSF_ERROR_BASE + 5)
#define RSCRYPTO_PKDS_CREATE_FAILED				(RSCRYPTO_ICSF_ERROR_BASE + 6)
#define RSCRYPTO_CKDS_READ_FAILED				(RSCRYPTO_ICSF_ERROR_BASE + 7)
#define RSCRYPTO_PKDS_READ_FAILED				(RSCRYPTO_ICSF_ERROR_BASE + 8)
#define RSCRYPTO_CKDS_WRITE_FAILED				(RSCRYPTO_ICSF_ERROR_BASE + 9)
#define RSCRYPTO_PKDS_WRITE_FAILED				(RSCRYPTO_ICSF_ERROR_BASE + 10)
#define RSCRYPTO_ICSF_TVV_EXCEPTION				(RSCRYPTO_ICSF_ERROR_BASE + 11)
#define RSCRYPTO_ICSF_BAD_LABEL					(RSCRYPTO_ICSF_ERROR_BASE + 12)
#define RSCRYPTO_ICSF_PRIVKEY_REQUIRED			(RSCRYPTO_ICSF_ERROR_BASE + 13)
#define RSCRYPTO_ICSF_TASKMODE_ONLY				(RSCRYPTO_ICSF_ERROR_BASE + 14)
#define RSCRYPTO_ICSF_CLEARKEY_ONLY				(RSCRYPTO_ICSF_ERROR_BASE + 15)
#define RSCRYPTO_CKDS_RECORDFOUND_WRONGTYPE		(RSCRYPTO_ICSF_ERROR_BASE + 16)
#define RSCRYPTO_ICSF_PROHIBIT_EXPORT			(RSCRYPTO_ICSF_ERROR_BASE + 17)
#define RSCRYPTO_ICSF_PUBKEY_REQUIRED			(RSCRYPTO_ICSF_ERROR_BASE + 18)
#define RSCRYPTO_ICSF_SERVICE_NOTAUTH			(RSCRYPTO_ICSF_ERROR_BASE + 19)
#define RSCRYPTO_ICSF_LABEL_NOTAUTH				(RSCRYPTO_ICSF_ERROR_BASE + 20)
#define RSCRYPTO_ICSF_BAD_TOKEN					(RSCRYPTO_ICSF_ERROR_BASE + 21)
#define RSCRYPTO_ICSF_RETAINED_KEY_READONLY		(RSCRYPTO_ICSF_ERROR_BASE + 22)
#define RSCRYPTO_ICSF_SIGVERIFY_THUMBS_DOWN		(RSCRYPTO_ICSF_ERROR_BASE + 23)
#define RSCRYPTO_ICSF_CLEARKEY_REDACTED			(RSCRYPTO_ICSF_ERROR_BASE + 24)
#define RSCRYPTO_ICSF_LENGTH_ERROR				(RSCRYPTO_ICSF_ERROR_BASE + 25)

#define RSCRYPTO_GETPROTECTEDKEY_FAILED   (RSCRYPTO_ICSF_ERROR_BASE + 30)

#define RSCRYPTO_ICSF_INTERNAL_ERROR			(RSCRYPTO_ICSF_ERROR_BASE + 40)

#define RSCRYPTO_ICSFERR_UNRECOGNIZED			(RSCRYPTO_ICSF_ERROR_BASE + 50)


#define RSCRYPTO_OPENSSL_ERROR_BASE				(RSCRYPTO_BASE_ERROR + 2000)

#define RSCRYPTO_OPENSSL_EVP_CTXINIT			(RSCRYPTO_OPENSSL_ERROR_BASE + 1)
#define RSCRYPTO_OPENSSL_EVP_UPDATE				(RSCRYPTO_OPENSSL_ERROR_BASE + 2)
#define RSCRYPTO_OPENSSL_EVP_FINAL				(RSCRYPTO_OPENSSL_ERROR_BASE + 3)
#define RSCRYPTO_OPENSSL_EVP_DIGESTINIT			(RSCRYPTO_OPENSSL_ERROR_BASE + 4)
#define RSCRYPTO_OPENSSL_EVP_DIGESTUPDATE		(RSCRYPTO_OPENSSL_ERROR_BASE + 5)
#define RSCRYPTO_OPENSSL_EVP_DIGESTFINAL		(RSCRYPTO_OPENSSL_ERROR_BASE + 6)


#define RSCRYPTO_PKCS11_ERROR_BASE    (RSCRYPTO_BASE_ERROR + 3000)

#define RS_PKCS11_DLOPEN              (RSCRYPTO_PKCS11_ERROR_BASE + 1)
#define RS_PKCS11_DLSYM               (RSCRYPTO_PKCS11_ERROR_BASE + 2)
#define RS_PKCS11_TOKEN_NOTFOUND      (RSCRYPTO_PKCS11_ERROR_BASE + 3)
#define RS_PKCS11_BAD_LABEL           (RSCRYPTO_PKCS11_ERROR_BASE + 4)
#define RS_PKCS11_ENV_NOTINITIALIZED  (RSCRYPTO_PKCS11_ERROR_BASE + 5)
#define RS_PKCS11_MAX_RANDOM_EXCEEDED (RSCRYPTO_PKCS11_ERROR_BASE + 6)
#define RS_PKCS11_OBJECT_NOTFOUND     (RSCRYPTO_PKCS11_ERROR_BASE + 7)
#define RS_PKCS11_BAD_BITLENGTH       (RSCRYPTO_PKCS11_ERROR_BASE + 8)
#define RS_PKCS11_ALREADY_OPEN        (RSCRYPTO_PKCS11_ERROR_BASE + 9)
#define RS_PKCS11_ALREADY_CLOSED      (RSCRYPTO_PKCS11_ERROR_BASE + 10)
#define RS_PKCS11_REQUIRES_READWRITE  (RSCRYPTO_PKCS11_ERROR_BASE + 11)
#define RS_PKCS11_MAXLEN_EXCEEDED     (RSCRYPTO_PKCS11_ERROR_BASE + 12)
#define RS_PKCS11_INVALID_SIGDIGEST_TYPE (RSCRYPTO_PKCS11_ERROR_BASE + 13)


#endif /* RSCRYPTO_ERRORS_H_ */

/*
  This program and the accompanying materials are
  made available under the terms of the Eclipse Public License v2.0 which accompanies
  this distribution, and is available at https://www.eclipse.org/legal/epl-v20.html

  SPDX-License-Identifier: EPL-2.0

  Copyright Contributors to the Zowe Project.
*/
